summaryrefslogtreecommitdiffstats
path: root/kword/KWTextFrameSet.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-18 18:12:30 -0600
committerTimothy Pearson <[email protected]>2011-12-18 18:12:30 -0600
commit11191ef0b9908604d1d7aaca382b011ef22c454c (patch)
treed38f0ccd8bfcc9756f5cfc42fb2ad1dad351e6aa /kword/KWTextFrameSet.cpp
parentc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (diff)
downloadkoffice-11191ef0b9908604d1d7aaca382b011ef22c454c.tar.gz
koffice-11191ef0b9908604d1d7aaca382b011ef22c454c.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kword/KWTextFrameSet.cpp')
-rw-r--r--kword/KWTextFrameSet.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kword/KWTextFrameSet.cpp b/kword/KWTextFrameSet.cpp
index 43a1de5a..7f7a78a3 100644
--- a/kword/KWTextFrameSet.cpp
+++ b/kword/KWTextFrameSet.cpp
@@ -3161,7 +3161,7 @@ void KWTextFrameSetEdit::pasteData( TQMimeSource* data, int provides, bool drop
}
else if ( provides & KWView::ProvidesPlainText )
{
// Note: TQClipboard::text() seems to do a better job than tqencodedData( "text/plain" )
// In particular it handles charsets (in the mimetype).
const TQString text = TQApplication::tqclipboard()->text();
const bool removeSelected = !drop;
@@ -3188,7 +3188,7 @@ KCommand* KWTextFrameSetEdit::pasteOasisCommand( TQMimeSource* data )
TQCString returnedTypeMime = KoTextObject::providesOasis( data );
if ( !returnedTypeMime.isEmpty() )
{
- TQByteArray arr = data->tqencodedData( returnedTypeMime );
+ TQByteArray arr = data->encodedData( returnedTypeMime );
Q_ASSERT( !arr.isEmpty() );
if ( arr.size() )
return textFrameSet()->pasteOasis( cursor(), arr, true );
@@ -3161,7 +3161,7 @@ void KWTextFrameSetEdit::pasteData( TQMimeSource* data, int provides, bool drop
else if ( provides & KWView::ProvidesPlainText )
{
- // Note: TQClipboard::text() seems to do a better job than tqencodedData( "text/plain" )
+ // Note: TQClipboard::text() seems to do a better job than encodedData( "text/plain" )
// In particular it handles charsets (in the mimetype).
const TQString text = TQApplication::tqclipboard()->text();